@@ -373,7 +373,12 @@ class ModSn(ModInput):
             hardware_serial = int(matcher.group("hardware_serial"), 16)
             manu = int(matcher.group("manu"), 16)
             software_serial = int(matcher.group("software_serial"), 16)
-            hardware_type = lcn_defs.HardwareType(int(matcher.group("hardware_type")))
+            try:
+                hardware_type = lcn_defs.HardwareType(
+                    int(matcher.group("hardware_type"))
+                )
+            except ValueError:  # unknown hardware type
+                hardware_type = lcn_defs.HardwareType(-1)
             return [ModSn(addr, hardware_serial, manu, software_serial, hardware_type)]
 
         return None
@@ -729,9 +734,9 @@ class ModStatusVar(ModInput):
             ret: List[Input] = []
             addr = LcnAddr(int(matcher.group("seg_id")), int(matcher.group("mod_id")))
             for thrs_id in range(5):
-                var = lcn_defs.Var.var_id_to_var(int(matcher.group("id")) - 1)
+                var = lcn_defs.Var.thrs_id_to_var(0, thrs_id)
                 value = lcn_defs.VarValue.from_native(
-                    int(matcher.group("value{:d}".format(thrs_id + 1)))
+                    int(matcher.group(f"value{thrs_id + 1}"))
                 )
                 ret.append(ModStatusVar(addr, var, value))
             return ret
